The Application Class
=====================

The :class:`~cf.application.Application` class is the central object in
:program:`CrunchyFrog`. An instance of the class is shared between all
other relevant objects in the application.


.. autoclass:: cf.application.Application
   :members:
